@@ -499,32 +499,28 @@ more items than that, use completing read instead."
 ;; Copy-paste job from gud.el:perldb (shoulders of giants, etc)
 (defun ps/debug-file-debug-command (command dir-debug-from)
   "Run perldb on program FILE in buffer *gud-FILE*."
-  (let ((command-line (ps/gud-query-cmdline command)))
-    (setq gud-chdir-before-run t)
-    (setq gud-perldb-command-name command)
-
-    (gud-common-init command-line 'gud-perldb-massage-args 'gud-perldb-marker-filter)
-    (set (make-local-variable 'gud-minor-mode) 'perldb)
-
-    (gud-def gud-break  "b %l"         "\C-b" "Set breakpoint at current line.")
-    (gud-def gud-remove "B %l"         "\C-d" "Remove breakpoint at current line")
-    (gud-def gud-step   "s"            "\C-s" "Step one source line with display.")
-    (gud-def gud-next   "n"            "\C-n" "Step one line (skip functions).")
-    (gud-def gud-cont   "c"            "\C-r" "Continue with display.")
+  (let ((command-line (ps/gud-query-cmdline command))
+        (gud-chdir-before-run nil)
+        (gud-perldb-command-name command))
+    (ps/with-default-directory
+     dir-debug-from
+     (gud-common-init command-line 'gud-perldb-massage-args 'gud-perldb-marker-filter)
+     (set (make-local-variable 'gud-minor-mode) 'perldb)
+     
+     (gud-def gud-break  "b %l"         "\C-b" "Set breakpoint at current line.")
+     (gud-def gud-remove "B %l"         "\C-d" "Remove breakpoint at current line")
+     (gud-def gud-step   "s"            "\C-s" "Step one source line with display.")
+     (gud-def gud-next   "n"            "\C-n" "Step one line (skip functions).")
+     (gud-def gud-cont   "c"            "\C-r" "Continue with display.")
                                         ;  (gud-def gud-finish "finish"       "\C-f" "Finish executing current function.")
                                         ;  (gud-def gud-up     "up %p"        "<" "Up N stack frames (numeric arg).")
                                         ;  (gud-def gud-down   "down %p"      ">" "Down N stack frames (numeric arg).")
-    (gud-def gud-print  "p %e"          "\C-p" "Evaluate perl expression at point.")
-    (gud-def gud-until  "c %l"          "\C-u" "Continue to current line.")
+     (gud-def gud-print  "p %e"          "\C-p" "Evaluate perl expression at point.")
+     (gud-def gud-until  "c %l"          "\C-u" "Continue to current line.")
 
-    (setq comint-prompt-regexp "^  DB<+[0-9]+>+ ")
-    (setq paragraph-start comint-prompt-regexp)
-
-    ;; Chdir to the project dir the first thing we do, inside the perl debugger
-    (comint-send-string (current-buffer) (format "chdir('%s');\n" dir-debug-from))
-    ;;;; TODO: replace the first line in the buffer indicating cwd with the real cwd
-
-    (run-hooks 'perldb-mode-hook)))
+     (setq comint-prompt-regexp "^  DB<+[0-9]+>+ ")
+     (setq paragraph-start comint-prompt-regexp)
+     (run-hooks 'perldb-mode-hook))))
 
 
 
